#
# spec file for package python-sunpy
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
# docs directory needed for tests not in source archive
%bcond_with     test
Name:           python-sunpy
Version:        0.8.4
Release:        lp150.1.18
Summary:        SunPy: Python for Solar Physics
License:        BSD-2-Clause and BSD-3-Clause and Apache-2.0 and MIT
Group:          Development/Languages/Python
Url:            https://github.com/sunpy/sunpy
Source:         https://files.pythonhosted.org/packages/source/s/sunpy/sunpy-%{version}.tar.gz
BuildRequires:  %{python_module SQLAlchemy}
BuildRequires:  %{python_module astropy >= 1.0.0}
BuildRequires:  %{python_module astropy-helpers >= 1.0.0}
BuildRequires:  %{python_module beautifulsoup4}
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module matplotlib >= 1.1}
BuildRequires:  %{python_module numpy-devel > 1.7.1}
BuildRequires:  %{python_module pandas >= 0.12.0}
BuildRequires:  %{python_module requests}
BuildRequires:  %{python_module scikit-image}
BuildRequires:  %{python_module scipy}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module suds-jurko}
BuildRequires:  fdupes
BuildRequires:  python-backports.functools_lru_cache
BuildRequires:  python-rpm-macros
%if %{with test}
BuildRequires:  %{python_module pytest}
%endif
Requires:       python-astropy >= 1.0.0
Requires:       python-matplotlib >= 1.1
Requires:       python-numpy > 1.7.1
Requires:       python-pandas >= 0.12.0
Requires:       python-scipy
%ifpython2
BuildRequires:  python-backports.functools_lru_cache
%endif
Recommends:     python-SQLAlchemy
Recommends:     python-beautifulsoup4
Recommends:     python-glymur
Recommends:     python-requests
Recommends:     python-scikit-image
Recommends:     python-suds-jurko
Recommends:     python-wcsaxes >= 0.8

%python_subpackages

%description
SunPy is a Python library for solar physics data analysis.

%prep
%setup -q -n sunpy-%{version}
chmod -x sunpy/data/test/cor1_20090615_000500_s4c1A.fts

%build
export CFLAGS="%{optflags}"
%python_exec setup.py build --offline

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitearch}

%if %{with test}
%check
%python_exec setup.py test
%endif

%files %{python_files}
%defattr(-,root,root,-)
%doc README.md CHANGELOG.rst RELEASE.md 
%doc licenses/
%{python_sitearch}/sunpy
%{python_sitearch}/sunpy-%{version}-py*.egg-info

%changelog
* Mon Feb 26 2018 toddrme2178@gmail.com
- Update to version 0.8.4
  + Bug Fixes
  * Improve detection of ``SkyCoord`` frame instantiation when distance is
    `1*u.one`. This fixes a plotting bug with ``WCSAxes`` in Astropy 3.0 [#2465]
  * removed `wavelnth` keyword in meta desc of Maps to avoid using non standard FITS keyword like `nan` [#2427]
  * Change the default units for HPC distance from `u.km` to `None`. [#2465]
- Update to version 0.8.3
  + Bug Fixes
  * `~sunpy.net.dataretriever.clients.XRSClient` now reports time ranges of files correctly. [#2364]
  * Make parse_time work with datetime64s and pandas series [#2370]
  * CompositeMap axes scaling now uses map spatial units [#2310]
  * Moved license file to root of repository and updated README file [#2326]
  * Fix docstring formatting for net.vso.attrs [#2309]]
  * Fix coloring of ticks under matplotlib 2.0 default style [#2320]
  * Always index arrays with tuples in `ImageAnimator` [#2320]
  * Added links to possible attrs for FIDO in guide [#2317] [#2289]
  * Updated GitHub Readme [#2281] [#2283]
  * Fix matplotlib / pandas 0.21 bug in examples [#2336]
  * Fixes the off limb enhancement example [#2329]
  * Changes to masking hot pixels and picking bright pixels examples [#2325] [#2319]
  * Travis CI fix for numpy-dev build [#2340]
  * Updated masking brightest pixel example [#2338]
  * Changed TRAVIS cronjobs [#2338]
  * Support array values for `obstime` for coordinates and transformations [#2342] [#2346]
  * Updated Gallery off limb enhance example [#2337]
  * Documentation fixes for VSO [#2354] [#2353]
  * All tests within the documentation have been fixed [#2343]
  * Change to using pytest-remotedata for our online tests [#2345]
  * Fixed upstream astropy/numpy documentation issues [#2359]
  * Documentation for Map improved [#2361]
  * Fix the output units of pixel_to_world [#2362]
  * Documentation for Database improved [#2355]
  * Added test for mapsave [#2365]
  * Documentation for Sun improved [#2369]
* Thu Jun 22 2017 alarrosa@suse.com
- Initial release of python-sunpy 0.7.8
